@@ -2,7 +2,7 @@ package Atomic::Pipe;
 use strict;
 use warnings;
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 use IO();
 use Carp qw/croak/;
@@ -11,7 +11,12 @@ BEGIN {
     # POSIX says writes of 512 or less are atomic, but some platforms allow for
     # larger ones.
     require POSIX;
-    *PIPE_BUF = POSIX->can('PIPE_BUF') || sub() { 512 };
+    if (POSIX->can('PIPE_BUF') && eval { POSIX::PIPE_BUF() }) {
+        *PIPE_BUF = \&POSIX::PIPE_BUF;
+    }
+    else {
+        *PIPE_BUF = sub() { 512 };
+    }
 }
 
 use Errno qw/EINTR EAGAIN/;
